#
# spec file for package obs-service-source_validator
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version}
%define build_pkg_name build
%else
%define build_pkg_name obs-build
%endif

Name:           obs-service-source_validator
Version:        0.39+2
Release:        1.2
Summary:        An OBS source service: running all the osc source-validator checks
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/openSUSE/obs-service-source_validator
# use osc service mr to update
Source:         %{name}-%{version}.tar.xz
BuildRequires:  %{build_pkg_name}
BuildRequires:  zstd
Requires:       %{_bindir}/cpio
Requires:       %{_bindir}/xmllint
Requires:       %{build_pkg_name}
Requires:       bzip2
Requires:       diffutils
Requires:       patch
Requires:       perl-TimeDate
Requires:       unzip
Requires:       xz
Requires:       zstd
Provides:       osc-source_validator = %{version}
Obsoletes:      osc-source_validator <= 0.1
BuildArch:      noarch
%if 0%{?suse_version}
Requires:       gpg2
%else
# Fedora
Requires:       gnupg2
%endif

%description
This is a source service for openSUSE Build Service.

This service runs all checks as required by openSUSE:Factory project. This can be used
to guarantee that all checks succeed also on the service side. This plugin can be
used via project wide defined services.

%prep
%setup -q

%build
:

%install
mkdir -p %{buildroot}%{_datadir}/licenses
%make_install

%check
%make_build test

%files
%license COPYING
%if 0%{?suse_version} <= 1320
%dir %{_datadir}/licenses
%endif
%dir %{_prefix}/lib/obs
%{_prefix}/lib/obs/service

%changelog
* Tue Jan 14 2025 dimstar@opensuse.org
- Update to version 0.39+2:
  * helpers/check_patches_applied: Fix detection of applying nonexisting patches
* Wed Oct 30 2024 dmueller@suse.com
- Update to version 0.39:
  * Handle package git repositories for tracking (fixes #143)
  * helpers/check_patches_applied: Also check whether patch 0 is applied
  * helpers/check_patches_applied: Match #%%%%patch* as well (#136)
  * helpers/check_patches_applied: Recognize " # %%patch" as comment
* Wed Sep 11 2024 Marcus Meissner <meissner@suse.com>
- require bzip2,xz and zstd which are used in gpg verification
* Thu Aug 29 2024 adrian@suse.de
- Update to version 0.38:
  * Fix 20-files-present-and-referenced against osc 1.9.0 (osclib_version 2.0)
* Mon Aug 12 2024 Marcus Rueckert <mrueckert@suse.de>
- Fix runtime requires: the source validator needs cmp -> Requires
  for diffutils
* Wed Jul  3 2024 Dirk Müller <dmueller@suse.com>
- update to 0.37:
  * Fix unzip test in 20-files-present-and-referenced
  (same like previous update)
- explicitly require unzip as busybox-unzip is not sufficient
* Thu May 23 2024 dimstar@opensuse.org
- Update to version 0.36+2:
  * Fix unzip test in 20-files-present-and-referenced
* Tue May 21 2024 Fabian Vogt <fvogt@suse.com>
- Require unzip, needed for 0.36
* Thu May 16 2024 dmueller@suse.com
- Update to version 0.36:
  * Forbid encrypted zip files
* Tue May 14 2024 Lubos Kocman <lubos.kocman@suse.com>
- Use bz2 compression to enable builds with debhelper
  * Debian/Ubuntu builds now work fine.
  * Allows rebuild packages with osc in ubuntu image on github
- Add deb dependency on libmodule-build-perl and libxml2-utils
* Fri May 10 2024 Fabian Vogt <fvogt@suse.com>
- Require cpio, needed for .obscpio support
* Mon Apr 29 2024 Kentaro Ishii <sony.pcv.s520@gmail.com>
- Fix dependency to obs-build for Fedora
* Wed Apr  3 2024 dmueller@suse.com
- Update to version 0.35:
  * Modifications in line with latest cargo vendor tool
* Tue Jan 30 2024 Marcus Rueckert <mrueckert@suse.de>
- since https://github.com/openSUSE/obs-service-source_validator/commit/0cb832185b71e869bb84fc995f483275c5c4158d
  rpm-build seems to be unused. remove the dependency.
* Fri Nov 24 2023 ro@suse.com
- Update to version 0.34:
  * helpers/functions: Always treat all *.spec files as recipes
* Tue Aug  1 2023 dmueller@suse.com
- Update to version 0.33:
  * 20-files-present-and-referenced: Check for files in *.obscpio
  * 20-files-present-and-referenced: Use correct variable
* Tue Jul 18 2023 dmueller@suse.com
- Update to version 0.32:
  * Add autonumbering patch/source lines
  * Fix handling of packages with neither *.spec nor _multibuild
* Fri Jun 30 2023 dmueller@suse.com
- Update to version 0.31:
  * Also ignore .gitattributes file
  * Exempt obs services from the cargo audit requirement
  * helpers/spec_query: Handle %%include
  * Unify _multibuild handling and do it like OBS
* Fri May  5 2023 dmueller@suse.com
- Update to version 0.30:
  * skip debian.lintian-overrides as well
* Wed May  3 2023 dmueller@suse.com
- Update to version 0.29:
  * Do not check for all _multibuild flavors if spec does not
    conitionalize on BUILD_FLAVOR
  * Add GitHub Actions
* Mon Nov  7 2022 dmueller@suse.com
- Update to version 0.28:
  * Add ignore list
* Fri Oct 28 2022 dmueller@suse.com
- Update to version 0.28:
  * also avoid expansion on grep
  * add quotes around BASE to avoid shell expansion
* Tue Oct 25 2022 dmueller@suse.com
- Update to version 0.27:
  * Fix detection of rust-packaging
* Fri Oct 21 2022 ro@suse.de
- Update to version 0.27:
  * use current directory when not given to avoid crashes
* Fri Oct 21 2022 ro@suse.de
- Update to version 0.27:
  * Fix python3 line
  * Apply feedback
  * Add new validator to check rust audit is enforced
* Thu Oct  6 2022 dmueller@suse.com
- Update to version 0.27:
  * Do not use temporary file for GPG validation
* Tue Sep 20 2022 dmueller@suse.com
- Update to version 0.27:
  * Convert all egrep/fgrep calls to grep -E/-F, respectively.
- use zstd for tarball compression
- spec file cleanups
* Thu Aug 11 2022 ro@suse.de
- Update to version 0.26:
  * Skip non-existing files from the invalid-patches check
  * Treat to-be-deleted patches as nonexisting for the source-tracked check
  * Update README with a clearer mission/scope
  * cleanup: make variable name a valid english word
* Thu Aug  4 2022 Dirk Müller <dmueller@suse.com>
- require patch for patch-format checking
* Thu Aug  4 2022 dmueller@suse.com
- Update to version 0.25 (bsc#1202132)
  * Reject empty or ill-formatted patches
* Thu Jul  7 2022 dmueller@suse.com
- Update to version 0.24:
  * Use ERROR for prefixing errors
  * Split out GPG validation into own check and improve it
* Tue Mar 22 2022 dmueller@suse.com
- Update to version 0.23:
  * Allow mode=manual services
  * spec_query: add elif support
  * 45-stale-changes: Also read <package/> in _multibuild
* Thu Feb  3 2022 ro@suse.de
- Update to version 0.22:
  * display diff if previous file is present in 20-files-present-and-referenced
  * 45-stale-changes: Use xmllint for listing multibuild flavors
  * 45-stale-changes: Don't break if there is no *.spec
  * 45-stale-changes allow for multibuild specfiles with empty default flavour
  * No need to compress buildtime generated tarballs
  * Fix running the checks on a directory with whitespace in its path
  * spec_query: print line numbers on %%if/%%else/%%endif error
  * 20-files-present-and-references: do not complain about debian.*.triggers
* Mon Dec 20 2021 dimstar@opensuse.org
- Update to version 0.21:
  * 45-stale-changes allow for multibuild specfiles with empty default flavour
  * Fix running the checks on a directory with whitespace in its path
  * spec_query: print line numbers on %%if/%%else/%%endif error
  * 20-files-present-and-references: do not complain about debian.*.triggers
* Tue Mar  9 2021 adrian@suse.de
- Update to version 0.21:
  * No need to compress buildtime generated tarballs
* Fri Dec 11 2020 adrian@suse.de
- Update to version 0.20:
  * One .changes file per package is enough
* Fri Dec  6 2019 Adrian Schröter <adrian@suse.de>
- Update to version 0.19:
  * allow _multibuild to handle multiple specs
  * The --buildflavor option was missing from the help output
  * 70-baselibs: do not run subshells
  * allow -MACRO ending for changes file on multibuild setups
  * skip source files checks for product definition directories
  * Add missing dependency to the debian/control file
* Mon Jun 25 2018 ro@suse.de
- Update to version 0.18:
  * /usr/include/X11 is still a valid path.
* Thu Jun 14 2018 fschreiner@suse.de
- Update to version 0.17:
  * make path for helpers variable
  * fix for #bsc985980
* Tue May 15 2018 ro@suse.de
- Update to version 0.16:
  * 60-spec-filelist: check for LICENSE or COPYING files
    marked as %%doc
* Wed Mar 14 2018 opensuse-packaging@opensuse.org
- Update to version 0.15:
  * 70-baselibs: call spec_query with and without the
  - -no-conditionals switch
* Fri Mar  9 2018 opensuse-packaging@opensuse.org
- Update to version 0.14:
  * 70-baselibs: call spec_query with --no-conditionals so that
    checking package tevent sees the python3-tevent package for
    the baselibs checker
  * Build-depend on obs-build to fix Debian build
* Tue Feb  6 2018 adrian@suse.de
- Update to version 0.13:
  * move multibuild or multi spec in front
  * add glibc testcase using multibuild
  * support _multibuild files when validating sources
* Tue Feb  6 2018 adrian@suse.de
- Update to version 0.13
  * do not use "--no-conditionals" for baselibs check
* Thu Jan 18 2018 fschreiner@suse.de
- Update to version 0.12:
  * fix for continous lines in macros
* Tue Jan 16 2018 fschreiner@suse.de
- Update to version 0.11:
  * fix for macro continuation
  * activating initial test cases
  * .gitignore for vim swap files
* Thu Jan 11 2018 fschreiner@suse.de
- Update to version 0.10:
  * Do not call helpers/spec_query with --unique-sources in 70-baselibs
  * Keep if statements in line continuation contexts
  * Fix --keep-name-conditionals code in helpers/spec_query
* Mon Dec 11 2017 fschreiner@suse.de
- Update to version 0.9:
  * fixes boo#1072375
  * check *_source.changes if they are valid debian source change files
* Wed Nov 29 2017 adrian@suse.de
- Update to version 0.7:
  * Do not ignore conditionals of the form "%%if ... %%{name} ..."
  * Add --keep-name-conditionals option to helpers/spec_query
  * Do not fail in case of ambiguous source tags
  * Use priviate --homedir when calling gpg
* Mon Oct  9 2017 jayvdb@gmail.com
- Update obs-service-source_validator.spec
  * Add explicit dependency on obs-build so that osc
    does not fail on distributions other than openSUSE.
* Fri Sep 22 2017 ro@suse.de
- Update to version 0.6+git20170922.230bbc4:
  * deal with nil, flavor defines in output_versions
  * defining flavor in last change was not needed, remove
  * 45-stale-changes: use spec_query instead of output_versions
    using the specfile parser from the build package
    (boo#1059858)
* Wed Aug 30 2017 tchvatal@suse.com
- Update to version 0.6+git20170830.0775ae8:
  * Fix typo in egrep _service
  * Refactor helpers/spec_sources into helpers/spec_query
  * Use helpers/spec_query in 20-files-present-and-referenced
  * Do not use rpm --specfile to query the subpackage names
  * Remove unused RPMBUILD variable
  * Do not use a grouping
  * Silence another build warning wrt issue #54
* Fri Aug 11 2017 adrian@suse.de
- Update to version 0.6+git20170811.369eb25:
  * ignore expand errors with macro scripts
* Thu Aug 10 2017 mstrigl@suse.com
- Update to version 0.6+git20170809.6818366:
  * Ignore not referenced appimage.yml file
  * Don't use rpmbuild to extract sources, patches etc. from a spec (bnc#938556 CVE-2017-9274)
* Wed Jul 19 2017 tchvatal@suse.com
- Update to version 0.6+git20170719.d4384e5:
  * Don't complain about Debian manpages files missing in *.spec
  * Add README.md file
  * Fix service run mode check for localonly
  * Add 80-multibuild_xor_multispec: only multibuild OR multispec is supported
  * extract GPG_OPTIONS variable for multiple runs
  * For signature verification, use trust model "always"
* Sat Jul 15 2017 tchvatal@suse.com
- Update to version 0.6+git20170715.607b861:
  * - support obspcio also in osc case
  * Remove provides and obsoletes from the spec
* Wed Jan 11 2017 adrian@suse.de
- Update to version 0.6+git20170111.82ea590:
  * accept reproducable CI source builds
  * accept .obsinfo and .obscpio archives
  * accept further modes of services
* Wed Dec  7 2016 opensuse-packaging@opensuse.org
- Update to version 0.6+git20161207.70e9d99:
  * 20-files-present-and-referenced fix case where rpmbuild emits a warning but the specfile does not list sources or patches (bnc#1013981)
* Thu Jul  7 2016 adrian@suse.de
- Update to version 0.6+git20160707.a6ff89d:
  + fix debian.series using patches with patch levels
* Fri Jun 17 2016 fschreiner@suse.de
- Update to version 0.6+git20160617.cfadcb0:
  * 20-files-present: Add patches from debian.series file to sources list.
  * 20-files-present: Add more debian standard files to ignore.
  * 20-files-present: do not use cat where/while not needed
* Tue May 31 2016 fschreiner@suse.de
- Update to version 0.6+git20160531.fbfe336:
  * baselibs.conf: targetname is a valid keyword
  * added checker for filenames
  * additional fixes for  boo#967610 and bsc#967265
  * enhanced regex to check
  * better quoting and checks for dot files
  * filter out single/double quotes and grave accent from filenames
* Mon Feb 22 2016 fschreiner@suse.de
- Update to version 0.6+git20160222.62c56d3:
  + turned off warnings to avoid misleading messages
  + fixes boo#967610
  + related to bsc#967265
* Thu Feb 18 2016 fschreiner@suse.de
- Update to version 0.6+git20160218.73d6618:
  + Attempt to fix <CI_CNT> and <B_CNT> handling in Release in a minimal invasive way.
  + 20-files-present-and-referenced: also look for *.sign files
  + various security and bug fixes (boo#967265)
  + removed bash 4 test syntax
* Wed Jun 24 2015 hib@hiberis.nl
- Add debian.dsc
- Use install target from Makefile
- Update to version 0.5+git20150622.3c3fa65:
  + Add install target to Makefile
  + Debianization
* Thu Jun 11 2015 adrian@suse.de
- Update to version 0.5+git20150611.b85a5d4:
  + unbreak source validator with packages using source services again
  * Not all _* files are xml
  * Don't complain about service generated files
* Wed May 27 2015 lnussel@suse.de
- Update to version 0.5+git20150527.6e08ec8:
  + baselibs.conf: ignore lines starting with #; comments might be welcome
  + baselibs.conf: 'arch' is also a valid keyword
  + Avoid trashing _service file
* Wed May 13 2015 lnussel@suse.de
- Update to version 0.5+git20150513.7c2f7ae:
  + fix checking _service file
  + baselibs verification: targettype is a nown keyword - treat it as a 'built package'
  + baselibs validation: pass if we have trouble parsing the .spec file (missing devel packages on the host)
* Mon Apr 20 2015 lnussel@suse.de
- Update to version 0.5+git20150420.23830c1:
  + Verify if the packages referenced by baselibs.conf are actually being built.
  + Check for disallowed services before missing files (#16)
  + add support for %%autosetup and %%autopatch
- use proper versioning in _service file and generate changes entry
* Tue Feb 17 2015 ro@suse.de
- fix 20-files-present-and-referenced for ocaml macro
* Thu Nov 13 2014 coolo@suse.com
- remove PKGBUILD file again as it breaks source validator
* Thu Nov 13 2014 coolo@suse.com
- update from git:
  - Don't use gpg's --pgp2 option which was removed in gnupg 2.1.0
* Mon Sep 29 2014 coolo@suse.com
- update from git:
  - allow all files mentioned in .dsc too
  - import old md5 based keys like for postfix and putty
* Thu Aug 14 2014 ro@suse.de
- update from git:
  - more work on dealing with util-linux
* Wed Aug 13 2014 ro@suse.de
- update from git:
  - hack for util-linux specfiles (bnc#891829)
* Wed Jun 25 2014 coolo@suse.com
- update to git (0.4):
  - warn about unmentioned baselibs.conf and rpmlintrc
  - Handle Jan Engelhardt tarball signatures that are done before
    compression
  - handle %%global like %%define in output_versions
  - Support ARM build hosts
  - do not complain about temporary directories when running source services (on server esp.)
  - also check for orphan files when _services are used
    When _service mode is disabled or loc
* Tue May 27 2014 t1locs@gmail.com
- Add rpm-build dependancy for centos 6
* Thu Jan  9 2014 adrian@suse.de
- add requires to xmllint which is used
* Tue Aug  6 2013 dmueller@suse.com
- update to latest git:
  2b2c89d  also check for orphan files when _services are used
  197b519  Check the Buildservice magic files (_link/_service)
    with xmllint
  a6d922c  Cleanup keyring check
  f936138  removed the incorrect basename checking, also do not look
    for .gpg files as we currently use either .sig or .asc
* Sun Jun 30 2013 adrian@suse.de
- fix dependency to gnupg2 for Fedora (bnc#827480)
* Tue Jun 18 2013 coolo@suse.com
- add patch from mmeissner to verify .sig files
- add _service to ease update
* Tue Feb 26 2013 ro@suse.de
- allow PKGBUILD build description file for archlinux
* Mon Feb  4 2013 ro@suse.de
- check_patches_applied: allow #patches as comment
* Fri Jan 18 2013 ro@suse.de
- also allow %%undefine
* Mon Jan  7 2013 ro@suse.de
- exit if tmpdir creation fails (bnc#796918)
* Wed Jun 13 2012 ro@suse.de
- also ignore Requires(.*) lines (bnc#724609)
* Wed Jun 13 2012 ro@suse.de
- allow %%{nil} just as %%nil
* Fri Apr 27 2012 ro@suse.de
- use --nodeps with rpmbuild in 20-files-present-and-referenced
* Mon Feb 27 2012 dmueller@suse.de
- fix requires for factory
* Tue Feb 14 2012 adrian@suse.de
- add requires to perl-TimeDate
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Feb 13 2012 ro@suse.com
- do not complain for commented out rpmlintrc lines
- Update 20-files-present-and-referenced to ignore .git and
  .emacs.backup
- Change bright yellow into good old brown
* Fri Sep 23 2011 adrian@suse.de
- rename osc-source_validator package into osc-service-source_validator
- obsolete osc-source_validator
- roll tar ball from new git at github.com
* Fri Jul  1 2011 ro@suse.de
- prevent dupes for Release and Version along with Name
* Mon May 30 2011 ro@suse.de
- fix bug with "Patch" in comments
* Mon May  9 2011 ro@novell.com
- try to fix bnc#679980
* Wed Apr 20 2011 ro@suse.de
- find another form of commenting out patches
  in check_patches_applied
* Sun Apr 17 2011 ro@suse.de
- Also check if files are tracked by osc
- catch some more syntax variants in check_patches_applied
- do tracked-check only in osc mode
* Tue Apr 12 2011 ro@suse.de
- activate the patches_applied check for real,
  errors out if errors found
* Mon Apr  4 2011 ro@suse.de
- add debian special files
* Wed Mar 30 2011 ro@suse.de
- add colors to output of check_patches_applied
  but no colors for batchmode
* Fri Feb 18 2011 jw@novell.com
- retry broken sr#59008
- added another set of runtime-fixes.diff
  * accept .orig and ~ files in working directories.
  * UI consistency improved.
* Sat Feb 12 2011 ro@novell.com
- 50-spec-version: show warning only once per specfile
* Thu Jan 13 2011 ro@suse.de
- move COPYING file to docdir (prevent permission denied trying
  to execute it as a checkscript)
* Thu Jan 13 2011 ro@suse.de
- switch source to git (gitorious/opensuse)
- convert_changes_to_rpm_changelog make regex a little stricter
  looking for date line
- 20-files-present-and-referenced add %%rubygems_requires to
  prunelist
- add some helper files to create tar and changes
- stale-changes: do not fail if there is no specfile present at all
- stale-changes: allow extra changes files if listed as source in a
  spec
* Tue Jan  4 2011 mcihar@suse.cz
- add Url pointing to wiki to spec file
* Tue Jan  4 2011 mcihar@suse.cz
- cleanup spec file using spec-cleaner
* Tue Jan  4 2011 mcihar@suse.cz
- create 0.1 tarball with incorporated patch and added license file
- adjust spec file for above changes
* Mon Oct  4 2010 adrian@suse.de
- do not complain about files starting with underscore, they are
  OBS special files in any case
* Sat May 22 2010 adrian@suse.de
- add some modification to survive some more examples
* Thu May 20 2010 ro@suse.de
- make the files executable
* Thu May 20 2010 ro@suse.de
- fill with some content
* Thu May 20 2010 adrian@suse.de
- initial package, no code yet, always succeeding
